Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
polypandas/__init__.py | (no class) | 9 | 0 | 0 | 100%
polypandas/exceptions.py | PolypandasError | 0 | 0 | 0 | 100%
polypandas/exceptions.py | PandasNotAvailableError | 1 | 0 | 0 | 100%
polypandas/exceptions.py | SchemaInferenceError | 0 | 0 | 0 | 100%
polypandas/exceptions.py | UnsupportedTypeError | 0 | 0 | 0 | 100%
polypandas/exceptions.py | (no class) | 8 | 0 | 0 | 100%
polypandas/factory.py | PandasFactory | 27 | 2 | 0 | 93%
polypandas/factory.py | pandas_factory._PydanticPandasFactory | 3 | 1 | 0 | 67%
polypandas/factory.py | (no class) | 71 | 11 | 0 | 85%
polypandas/io.py | DataIOError | 0 | 0 | 0 | 100%
polypandas/io.py | (no class) | 104 | 24 | 0 | 77%
polypandas/protocols.py | (no class) | 12 | 4 | 0 | 67%
polypandas/schema.py | (no class) | 181 | 58 | 0 | 68%
polypandas/testing.py | DataFrameComparisonError | 0 | 0 | 0 | 100%
polypandas/testing.py | (no class) | 74 | 9 | 0 | 88%
Total |  | 490 | 109 | 0 | 78%

No items found using the specified filter.